@@ -21,7 +21,7 @@ our $EXT_VER       = 'v6.2.0';
 our $EXT_FRAMEWORK = 'classic';
 
 sub BUILD ( $self, $args ) {
-    Pcore::Ext->SCAN( $self->{app}, 'classic' );
+    Pcore::Ext->SCAN( $self->{app}, Pcore::Share::Ext_v6_2_0->get_cfg, $EXT_FRAMEWORK );
 
     die qq[Ext app "$self->{ext_app}" not found] if !$Pcore::Ext::CFG->{app}->{ $self->ext_app };
 
