@@ -1,13 +1,12 @@
-package Pcore::Ext v0.3.3;
+package Pcore::Ext v0.3.4;
 
-use Pcore -dist;
+use Pcore -dist, -const;
 use Pcore::Ext::Context;
 use JavaScript::Packer;
-use Pcore::Share::Ext_v6_2_0;
 
 our $SCANNED;
 
-our $NS = 'Pcore';
+const our $NS => 'Pcore';
 
 our $CFG = {
     app        => undef,
@@ -15,13 +14,15 @@ our $CFG = {
     perl_class => undef,
 };
 
-our $EXT = P->cfg->load( $ENV->share->get('/data/ext-v6.2.0.json') );
+our $EXT;
 
-sub SCAN ( $self, $app, $framework ) {
+sub SCAN ( $self, $app, $ext, $framework ) {
     return if $SCANNED;
 
     $SCANNED = 1;
 
+    $EXT = $ext;
+
     my $namespaces;
 
     my $root_namespace = ref($app) . '::Ext';
@@ -253,7 +254,7 @@ sub _get_ctx ( $self, $class, $app, $framework ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 20                   | Subroutines::ProhibitExcessComplexity - Subroutine "SCAN" with high complexity score (35)                      |
+## |    3 | 19                   | Subroutines::ProhibitExcessComplexity - Subroutine "SCAN" with high complexity score (35)                      |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
