@@ -111,7 +111,14 @@ sub get_class ( $self, $name ) {
     if ( index( $name, '.' ) == -1 ) {
         my $colon_idx = index $name, '::';
 
-        if ( $colon_idx == -1 || $colon_idx > 0 ) {
+        if ( $colon_idx == -1 ) {
+
+            # search by perl class name, related to the current namespace
+            if ( my $class_name = $Pcore::Ext::CFG->{perl_class}->{"$self->{ctx}->{namespace}::$name"} ) {
+                return $Pcore::Ext::CFG->{class}->{$class_name};
+            }
+        }
+        elsif ( $colon_idx > 0 ) {
 
             # search by perl class name, related to the current namespace
             if ( my $class_name = $Pcore::Ext::CFG->{perl_class}->{"$self->{ctx}->{namespace}::$name"} ) {
@@ -154,7 +161,7 @@ sub get_class ( $self, $name ) {
     return;
 }
 
-sub to_js ( $self, $requires = undef ) {
+sub to_js ( $self ) {
     my $cfg = do {
         my $method = "EXT_$self->{ctx}->{generator}";
 
@@ -172,7 +179,7 @@ sub to_js ( $self, $requires = undef ) {
     }
 
     # create "requires" property
-    push $cfg->{requires}->@*, $requires ? $requires->@* : sort keys $self->{ctx}->{requires}->%*;
+    push $cfg->{requires}->@*, sort keys $self->{ctx}->{requires}->%*;
 
     # set alias
     $cfg->{alias} = $self->{ctx}->{alias} if $self->{ctx}->{alias};
